package com.github.itzilly.sbt.command

import net.minecraft.client.Minecraft
import net.minecraft.command.ICommandSender
import net.minecraft.util.ChatComponentText

/**
 * Wrapper for command execution context.
 *
 * Provides access to the command sender, arguments, and helper methods.
 *
 * @property sender The ICommandSender executing the command.
 * @property args The raw array of command arguments.
 */
class CommandContext(
    val sender: ICommandSender,
    var args: Array<out String>
) {

    /**
     * The client-side player instance.
     * Can be null in rare cases (e.g., not in-game).
     */
    val player get() = Minecraft.getMinecraft().thePlayer

    /**
     * Sends a chat message to the player.
     *
     * @param msg The message to send.
     */
    fun send(msg: String) {
        player?.addChatMessage(ChatComponentText(msg))
    }

    /**
     * Retrieves an argument at the given index, or null if not present.
     *
     * @param index The argument index.
     * @return The argument or null.
     */
    fun arg(index: Int): String? = args.getOrNull(index)

    /**
     * Retrieves an argument and throws if it's missing.
     *
     * @param index The argument index.
     * @param error Error message to show if argument is missing.
     * @return The argument string.
     * @throws IllegalArgumentException if missing.
     */
    fun require(index: Int, error: String): String {
        return args.getOrNull(index) ?: throw IllegalArgumentException(error)
    }
}
